#coding=utf-8


class Store(object):
    def __init__(self):
        pass

    def save_seed_page(self):
        pass

    def save_list_page(self):
        pass

    def save_detail_page(self):
        pass

    def get_list_page(self):
        pass

    def get_detail_page(self):
        pass
